@@ -20,11 +20,12 @@
 #include "dict_object.h"
 #include "dictionariesmodel.h"
 
-#include <QtQml>
+// Qt
+#include <QQmlEngine>
 
 void DictPlugin::registerTypes (const char *uri)
 {
-    Q_ASSERT(uri == QLatin1String("org.kde.plasma.private.dict"));
+    Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.plasma.private.dict"));
     qmlRegisterType<DictObject>(uri, 1, 0, "DictObject");
     qmlRegisterType<DictionariesModel>(uri, 1, 0, "DictionariesModel");
 }
