@@ -19,7 +19,8 @@
 
 #include "timer.h"
 
-#include <QProcess>
+#include <KProcess>
+#include <KShell>
 
 Timer::Timer(QObject *parent) : QObject(parent)
 {
@@ -28,6 +29,10 @@ Timer::Timer(QObject *parent) : QObject(parent)
 
 void Timer::runCommand(const QString &command)
 {
-    QProcess::startDetached(command, QStringList());
+    if (!command.isEmpty()) {
+        QStringList split = KShell::splitArgs(command);
+        const QString program = split.takeFirst();
+        QProcess::startDetached(program, split);
+    }
 }
 
