@@ -243,8 +243,8 @@ void SpellCheckRunner::match(Plasma::RunnerContext &context)
     } else {
         Plasma::QueryMatch match(this);
         match.setType(Plasma::QueryMatch::InformationalMatch);
-        match.setIconName(QStringLiteral("task-attention"));
-        match.setText(i18n("Could not find a dictionary."));
+        match.setIconName(QStringLiteral("data-error"));
+        match.setText(i18n("No dictionary found, please install hspell"));
         context.addMatch(match);
     }
 }
@@ -271,6 +271,6 @@ QMimeData * SpellCheckRunner::mimeDataForMatch(const Plasma::QueryMatch &match)
     return result;
 }
 
-K_EXPORT_PLASMA_RUNNER(krunner_spellcheck, SpellCheckRunner)
+K_EXPORT_PLASMA_RUNNER_WITH_JSON(SpellCheckRunner, "plasma-runner-spellchecker.json")
 
 #include "spellcheck.moc"
